#!/usr/bin/python
# -*- coding: UTF-8 -*-

__author__ = 'Markus Beuckelmann'
__author_email__ = 'email@markus-beuckelmann.de'
__version__ = '0.2.0'

__all__ = ['de', 'en', 'nl', 'it', 'es', 'fr', 'audiosamples', 'textsamples', 'images']

VERSION = __version__

import lltk.config as config
config['version'] = __version__